pub fn bcrypt_pbkdf(
passphrase: impl AsRef<[u8]>,
salt: &[u8],
rounds: u32,
output: &mut [u8],
) -> Result<(), Error>Expand description
The bcrypt_pbkdf function.
Arguments
passphrase- The passphrase to process.salt- The salt value to use as a byte vector.rounds- The number of rounds to apply.output- The resulting derived key is returned in this byte vector.
Errors
Error::InvalidParamLenifpassphrase.is_empty() || salt.is_empty().Error::InvalidRoundsifrounds == 0.Error::InvalidOutputLenifoutput.is_empty() || output.len() > 1024.